@@ -1,14 +1,17 @@
 package Galileo;
 use Mojo::Base 'Mojolicious';
 
-our $VERSION = '0.038';
+our $VERSION = '0.039';
 $VERSION = eval $VERSION;
 
 use File::Basename 'dirname';
+use File::Spec;
 use File::Spec::Functions qw'rel2abs catdir';
 use File::ShareDir 'dist_dir';
 use Cwd;
 
+use Mojo::Home;
+
 has db => sub {
   my $self = shift;
   my $schema_class = $self->config->{db_schema} or die "Unknown DB Schema Class";
@@ -21,16 +24,15 @@ has db => sub {
   return $schema;
 };
 
-has home_path => sub {
+has home => sub {
   my $path = $ENV{GALILEO_HOME} || getcwd;
-  return File::Spec->rel2abs($path);
+  return Mojo::Home->new(File::Spec->rel2abs($path));
 };
 
 has config_file => sub {
   my $self = shift;
   return $ENV{GALILEO_CONFIG} if $ENV{GALILEO_CONFIG};
-
-  return rel2abs( 'galileo.conf', $self->home_path );
+  return $self->home->rel_file('galileo.conf');
 };
 
 sub load_config {
@@ -40,7 +42,7 @@ sub load_config {
     file => $app->config_file,
     default => {
       db_schema  => 'Galileo::DB::Schema',
-      db_dsn => 'dbi:SQLite:dbname=' . $app->home->rel_file( 'galileo.db' ),
+      db_dsn => 'dbi:SQLite:dbname=' . $app->home->rel_file('galileo.db'),
       db_username => undef,
       db_password => undef,
       db_options => { sqlite_unicode => 1 },
@@ -124,18 +126,6 @@ sub _to_abs {
 sub startup {
   my $app = shift;
 
-  # set home folder
-  $app->home->parse( $app->home_path );
-
-  {
-    # setup logging path
-    # code stolen from Mojolicious.pm
-    my $mode = $app->mode;
-
-    $app->log->path($app->home->rel_file("log/$mode.log"))
-      if -w $app->home->rel_file('log');
-  }
-
   $app->load_config;
 
   {
@@ -188,8 +178,9 @@ sub startup {
     return $user->is_admin;
   });
 
-  $app->plugin( 'Memorize' );
-  $app->plugin( 'Galileo::Plugin::Modal' );
+  $app->plugin('Memorize');
+  $app->plugin('Galileo::Plugin::Modal');
+  $app->plugin('Humane', auto => 0);
 
   ## Routing ##
 
@@ -222,9 +213,6 @@ sub startup {
   $if_admin->websocket( '/store/user' )->to('admin#store_user');
   $if_admin->websocket( '/remove/page' )->to('admin#remove_page');
 
-  ## Additional Plugins ##
-  $app->plugin('Humane', auto => 0);
-  $app->plugin('ConsoleLogger') if $ENV{GALILEO_CONSOLE_LOGGER};
 }
 
 1;
@@ -270,10 +258,6 @@ This is the directory where L<Galileo> expects additional files. These include t
 
 This is the full path to a configuration file. The default is a file named F<galileo.conf> in the C<GALILEO_HOME> path, however this file need not actually exist, defaults may be used instead. This file need not be written by hand, it may be generated by the C<galileo config> command.
 
-=item C<GALILEO_CONSOLE_LOGGER>
-
-Use L<Mojolicious::Plugin::ConsoleLogger> to get additional state information and logger output sent to the browser console.
-
 =back
 
 =head2 The F<galileo> command line application
